@@ -11,6 +11,7 @@ import subprocess
 from phs3.phs3 import s3
 from phlogs.phlogs import phlogger
 import string
+from phcontext.phuploadfile import phUploadOriginalFilesFunc
 
 
 class PhContextFacade(object):
@@ -27,10 +28,12 @@ class PhContextFacade(object):
         self.job_path = path
         self.combine_path = path
         self.dag_path = path
+        self.upload_path = path
         self.name = ""
         self.job_prefix = "phjobs"
         self.combine_prefix = "phcombines"
         self.dag_prefix = "phdags"
+        self.upload_prefix = "upload"
 
     def execute(self):
         self.check_dir()
@@ -42,6 +45,8 @@ class PhContextFacade(object):
             self.command_run_exec()
         elif self.cmd == "dag":
             self.command_dag_exec()
+        elif self.cmd == "upload":
+            self.command_upload_exec()
         else:
             self.command_publish_exec()
 
@@ -56,6 +61,7 @@ class PhContextFacade(object):
         self.job_path = self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.job_prefix + "/" + self.name
         self.combine_path = self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.combine_prefix + "/" + self.name
         self.dag_path = self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.dag_prefix + "/"
+        self.upload_path = self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.upload_prefix+ "/"
         if self.cmd == "create":
             return self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.job_prefix + "/" + self.name
         elif self.cmd == "combine":
@@ -66,6 +72,9 @@ class PhContextFacade(object):
             return self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.job_prefix + "/" + self.name
         elif self.cmd == "publish":
             return self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.job_prefix + "/" + self.name
+        elif self.cmd == "upload":
+            # return self.get_workspace_dir() + "/" + self.get_current_project_dir() + "/" + self.upload_prefix + "/" + self.name
+            return os.getcwd() + "/" + self.upload_prefix + "/" + self.name
         else:
             raise Exception("Something goes wrong!!!")
 
@@ -158,7 +167,8 @@ class PhContextFacade(object):
         for _, dirs, _ in os.walk(job_dir):
             for key in dirs:
                 if (not key.startswith(".")) & (not key.startswith("__pycache__")):
-                    s3.put_object("s3fs-ph-storage", "airflow/dags/phjobs/" + key + ".py", job_dir + "/" + key + "/phjob.py")
+                    s3.put_object("s3fs-ph-storage", "airflow/dags/phjobs/" + key + ".py",
+                                  job_dir + "/" + key + "/phjob.py")
         for _, _, files in os.walk(self.dag_path):
             for key in files:
                 if not key.startswith("."):
@@ -225,3 +235,9 @@ class PhContextFacade(object):
         w.write(config.spec.linkage)
         w.write("\n")
         w.close()
+
+    def command_upload_exec(self):
+        print("command upload exec")
+        excel_path = self.path
+        phUploadOriginalFilesFunc(excel_path)
+
